## CSS - Demos - Layout 1

<script type="module" src="/web_components/js/css/layouts/WebC__CSS__Layout_1.mjs"></script>

<webc-container>
    <webc-css-layout-1        ></webc-css-layout-1> 
    <webc-css-layout-1 no-css ></webc-css-layout-1>
</webc-container>

<webc-container>
    <webc-css-layout-1></webc-css-layout-1>
    <webc-css-layout-1></webc-css-layout-1>
    <webc-css-layout-1></webc-css-layout-1>
</webc-container>
    